==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Pengaturan Umum</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Setelan Umum OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>OpenSCAD dapat dieksekusi</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>Impor OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Gunakan ViewProvider dalam tampilan struktur pohon</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Jika ini dicek, Objek Multmatrix akan menjadi Parametrik</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Gunakan Fitur Multmatrix</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Jumlah maksimum wajah poligon, prisma atau frustum. Jika fn lebih besar dari nilai ini, objek dianggap melingkar. Atur ke 0 tanpa batas</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Jumlah maksimum wajah untuk poligon (fn)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Ekspor OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>ukuran maksimum fragmen</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>sudut (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="../ui/openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>ukuran (fs)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>sifat busung</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Mesh fallback</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Defleksi</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>defleksi</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Pengaturan triangulasi</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Jika ini dicentang, Fitur akan mengklaim anak-anak mereka di pohon tampilan</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Cetak informasi debug di Konsol</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>path untuk executable OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Sudut minimum untuk fragmen</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Minimum ukuran dari fragmen</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="145"/>
      <source>Convert Edges to Faces</source>
      <translation>Mengkonversi Tepi ke Wajah</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="224"/>
      <source>Please select 3 objects first</source>
      <translation>Silahkan pilih 3 objek terlebih dahulu</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="1204"/>
      <source>Unsupported Function</source>
      <translation>Fungsi Tidak Didukung</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="1204"/>
      <source>Press OK</source>
      <translation>Tekan OK</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="268"/>
      <source>Add</source>
      <translation>Menambahkan</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="269"/>
      <source>Clear</source>
      <translation>Bersih</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="270"/>
      <source>as Mesh</source>
      <translation>sebagai Mesh</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="271"/>
      <source>Add OpenSCAD Element</source>
      <translation>Tambahkan Elemen OpenSCAD</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="344"/>
      <source>Perform</source>
      <translation>Melakukan</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="345"/>
      <source>Mesh Boolean</source>
      <translation>Mesh Boolean</translation>
    </message>
    <message>
      <location filename="../../OpenSCADUtils.py" line="585"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Kesalahan semua bentuk harus 2D atau keduanya harus 3D</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="95"/>
      <source>Unable to explode %s</source>
      <translation>Tidak dapat meledak % s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="386"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Tambahkan Elemen OpenSCAD...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="388"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Tambahkan elemen OpenSCAD dengan memasukkan kode OpenSCAD dan jalankan biner OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="122"/>
      <source>Color Shapes</source>
      <translation>Bentuk Warna</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="124"/>
      <source>Color Shapes by validity and type</source>
      <translation>Bentuk Warna menurut validitas dan tipe</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="143"/>
      <source>Convert Edges To Faces</source>
      <translation>Mengkonversi Tepi Untuk Wajah</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="204"/>
      <source>Expand Placements</source>
      <translation>Perluas Penempatan</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="206"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Perluas semua penempatan ke bawah FeatureTree</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="104"/>
      <source>Explode Group</source>
      <translation>Grup Explode</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="106"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Menghapus fusion, menerapkan penempatan untuk anak-anak, dan warna secara acak</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="421"/>
      <source>Hull</source>
      <translation>Lambung kapal</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="423"/>
      <source>Perform Hull</source>
      <translation>Lakukan Hull</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="185"/>
      <source>Increase Tolerance Feature</source>
      <translation>Tingkatkan Fitur Toleransi</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="187"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Buat Fitur yang memungkinkan untuk meningkatkan toleransi</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="400"/>
      <source>Mesh Boolean...</source>
      <translation>Mesh Boolean...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="402"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Ekspor benda-benda seperti jerat dan menggunakan OpenSCAD untuk melakukan operasi boolean</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="442"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="444"/>
      <source>Perform Minkowski</source>
      <translation>Lakukan Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="164"/>
      <source>Refine Shape Feature</source>
      <translation>Pertajam Bentuk Fitur</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="166"/>
      <source>Create Refine Shape Feature</source>
      <translation>Buat Perbaiki Bentuk Fitur</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="243"/>
      <source>Remove Objects and their Children</source>
      <translation>Hapus Objek dan Anak-anak mereka</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="245"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Menghapus objek yang dipilih dan semua anak yang tidak dirujuk dari benda lain</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="228"/>
      <source>Replace Object</source>
      <translation>Ganti Objek</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="230"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Mengganti sebuah objek di Pohon Fitur. Silahkan pilih tua, baru, dan objek induk</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="../../InitGui.py" line="80"/>
      <source>OpenSCAD Part tools</source>
      <translation>OpenSCAD bagian alat</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../InitGui.py" line="78"/>
      <source>OpenSCADTools</source>
      <translation>OpenSCADTools</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="id" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Pengaturan Umum</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Setelan Umum OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>OpenSCAD dapat dieksekusi</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>Impor OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Gunakan ViewProvider dalam tampilan struktur pohon</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Jika ini dicek, Objek Multmatrix akan menjadi Parametrik</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Gunakan Fitur Multmatrix</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Jumlah maksimum wajah poligon, prisma atau frustum. Jika fn lebih besar dari nilai ini, objek dianggap melingkar. Atur ke 0 tanpa batas</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Jumlah maksimum wajah untuk poligon (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Ekspor OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>ukuran maksimum fragmen</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>sudut (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>ukuran (fs)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>sifat busung</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Mesh fallback</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Defleksi</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>defleksi</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Pengaturan triangulasi</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Jika ini dicentang, Fitur akan mengklaim anak-anak mereka di pohon tampilan</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Cetak informasi debug di Konsol</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>path untuk executable OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Sudut minimum untuk fragmen</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Minimum ukuran dari fragmen</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="149"/>
      <source>Convert Edges to Faces</source>
      <translation>Mengkonversi Tepi ke Wajah</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="309"/>
      <source>Please select 3 objects first</source>
      <translation>Silahkan pilih 3 objek terlebih dahulu</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Unsupported Function</source>
      <translation>Fungsi Tidak Didukung</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Press OK</source>
      <translation>Tekan OK</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="347"/>
      <source>Add</source>
      <translation>Menambahkan</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="348"/>
      <source>Clear</source>
      <translation>Bersih</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="349"/>
      <source>as Mesh</source>
      <translation>sebagai Mesh</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="350"/>
      <source>Add OpenSCAD Element</source>
      <translation>Tambahkan Elemen OpenSCAD</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="423"/>
      <source>Perform</source>
      <translation>Melakukan</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="424"/>
      <source>Mesh Boolean</source>
      <translation>Mesh Boolean</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="623"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Kesalahan semua bentuk harus 2D atau keduanya harus 3D</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>Unable to explode %s</source>
      <translation>Tidak dapat meledak % s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="464"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Tambahkan Elemen OpenSCAD...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="468"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Tambahkan elemen OpenSCAD dengan memasukkan kode OpenSCAD dan jalankan biner OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="126"/>
      <source>Color Shapes</source>
      <translation>Bentuk Warna</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="129"/>
      <source>Color Shapes by validity and type</source>
      <translation>Bentuk Warna menurut validitas dan tipe</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="146"/>
      <source>Convert Edges To Faces</source>
      <translation>Mengkonversi Tepi Untuk Wajah</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="291"/>
      <source>Expand Placements</source>
      <translation>Perluas Penempatan</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="294"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Perluas semua penempatan ke bawah FeatureTree</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="110"/>
      <source>Explode Group</source>
      <translation>Grup Explode</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="113"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Menghapus fusion, menerapkan penempatan untuk anak-anak, dan warna secara acak</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="497"/>
      <source>Hull</source>
      <translation>Lambung kapal</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="500"/>
      <source>Perform Hull</source>
      <translation>Lakukan Hull</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="274"/>
      <source>Increase Tolerance Feature</source>
      <translation>Tingkatkan Fitur Toleransi</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="277"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Buat Fitur yang memungkinkan untuk meningkatkan toleransi</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="477"/>
      <source>Mesh Boolean...</source>
      <translation>Mesh Boolean...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="481"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Ekspor benda-benda seperti jerat dan menggunakan OpenSCAD untuk melakukan operasi boolean</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="516"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="519"/>
      <source>Perform Minkowski</source>
      <translation>Lakukan Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="195"/>
      <source>Mirror Mesh Feature...</source>
      <translation type="unfinished">Mirror Mesh Feature...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="198"/>
      <source>Create Mirror Mesh Feature</source>
      <translation type="unfinished">Create Mirror Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="165"/>
      <source>Refine Shape Feature</source>
      <translation>Pertajam Bentuk Fitur</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="168"/>
      <source>Create Refine Shape Feature</source>
      <translation>Buat Perbaiki Bentuk Fitur</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="324"/>
      <source>Remove Objects and their Children</source>
      <translation>Hapus Objek dan Anak-anak mereka</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="327"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Menghapus objek yang dipilih dan semua anak yang tidak dirujuk dari benda lain</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="312"/>
      <source>Replace Object</source>
      <translation>Ganti Objek</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="315"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Mengganti sebuah objek di Pohon Fitur. Silahkan pilih tua, baru, dan objek induk</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="254"/>
      <source>Resize Mesh Feature...</source>
      <translation type="unfinished">Resize Mesh Feature...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="258"/>
      <source>Create Resize Mesh Feature</source>
      <translation type="unfinished">Create Resize Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Scale Mesh Feature...</source>
      <translation type="unfinished">Scale Mesh Feature...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="228"/>
      <source>Create Scale Mesh Feature</source>
      <translation type="unfinished">Create Scale Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="83"/>
      <source>OpenSCAD Part tools</source>
      <translation>OpenSCAD bagian alat</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="81"/>
      <source>OpenSCADTools</source>
      <translation>OpenSCADTools</translation>
    </message>
  </context>
</TS>
